@@ -60,6 +60,10 @@ class ProfileReadContract(ProfileCreateContract):
     # Address
     address_code = serializers.CharField(max_length=64, allow_blank=True)
     address_coordinates = serializers.CharField(max_length=64, allow_blank=True)
+    # property
+    is_default = serializers.BooleanField()
+    credit_score = serializers.DecimalField(max_digits=3, decimal_places=2)
+    credit_score_created = serializers.DateTimeField()
 
 
 class RussianProfileUpdateContract(ProfileUpdateContract):
